import { type NextRequest, NextResponse } from "next/server"
import { loginAdmin } from "../../../../utils/auth"
import { cookies } from "next/headers"

export async function POST(request: NextRequest) {
  try {
    const { username, password } = await request.json()

    const result = await loginAdmin(username, password)

    if (result.success) {
      // Set the token as an HTTP-only cookie
      cookies().set({
        name: "auth-token",
        value: result.token,
        httpOnly: true,
        path: "/",
        maxAge: 60 * 60 * 24, // 1 day
        sameSite: "strict",
      })

      return NextResponse.json({ success: true })
    } else {
      return NextResponse.json({ success: false, error: result.error }, { status: 401 })
    }
  } catch (error) {
    return NextResponse.json({ success: false, error: "Internal server error" }, { status: 500 })
  }
}

